==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/comment/messages/pt-BR/base.php <==
<?php
return array (
  '<strong>Confirm</strong> comment deleting' => '<strong>Confirmar</strong> exclusão de comentário',
  '<strong>Delete</strong> comment?' => '<strong>Excluir</strong> comentário?',
  '<strong>Permalink</strong> to this comment' => '<strong>Permalink</strong> para este comentário',
  'Cancel' => 'Cancelar',
  'Cancel Edit' => 'Cancelar Alteração',
  'Comment' => 'Comentar',
  'Comment could not be saved!' => 'O comentário não pôde ser salvo!',
  'Comment has been deleted' => 'O comentário foi excluído',
  'Comment of blocked user.' => 'Comentário bloqueado pelo usuário.',
  'Comments' => 'Comentários',
  'Confirm' => 'Confirmar',
  'Delete' => 'Excluir',
  'Do you really want to delete this comment?' => 'Você realmente deseja excluir este comentário?',
  'Edit' => 'Alterar',
  'Edit your comment...' => 'Editar seu comentário...',
  'Permalink' => 'Link permanente',
  'Read full comment...' => 'Ler o comentário completo...',
  'Reason' => 'Motivo',
  'Reply' => 'Responder',
  'Send a notification to author' => 'Enviar uma notificação para o autor',
  'Show' => 'Exibir',
  'Show next {count} comments' => 'Mostrar os próximos {count} comentários',
  'Show previous {count} comments' => 'Mostrar {count} comentários anteriores',
  'The comment must not be empty!' => 'O comentário não pode estar vazio!',
  'Whenever a new comment was written.' => 'Sempre que um novo comentário foi escrito.',
  'Write a new comment...' => 'Escreva um novo comentário...',
  'Write a new reply...' => 'Escreva uma nova resposta ...',
  'comment' => 'Comentário',
  '{displayName} wrote a new comment ' => '{displayName} escreveu um novo comentário:',
);

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/comment/messages/pt-BR/base.php <==
<?php
return [
  '<strong>Confirm</strong> comment deleting' => '<strong>Confirmar</strong> exclusão de comentário',
  '<strong>Delete</strong> comment?' => '<strong>Excluir</strong> comentário?',
  '<strong>Permalink</strong> to this comment' => '<strong>Link Permanente</strong> para este comentário',
  'Cancel' => 'Cancelar',
  'Cancel Edit' => 'Cancelar Alteração',
  'Comment' => '💬',
  'Comment could not be saved!' => 'O comentário não pôde ser salvo!',
  'Comment has been deleted' => 'O comentário foi excluído',
  'Comment of blocked user.' => 'Comentário bloqueado pelo usuário.',
  'Comments' => 'Comentários',
  'Confirm' => 'Confirmar',
  'Delete' => 'Excluir',
  'Do you really want to delete this comment?' => 'Tem certeza que deseja excluir este comentário?',
  'Edit' => 'Alterar',
  'Edit your comment...' => 'Editar seu comentário...',
  'Permalink' => 'Link permanente',
  'Read full comment...' => 'Ler o comentário completo...',
  'Reason' => 'Motivo',
  'Reply' => '💬',
  'Send a notification to author' => 'Enviar uma notificação para o autor',
  'Show' => 'Exibir',
  'Show next {count} comments' => 'Mostrar os próximos {count} comentários',
  'Show previous {count} comments' => 'Mostrar {count} comentários anteriores',
  'The comment must not be empty!' => 'O comentário não pode estar vazio!',
  'Whenever a new comment was written.' => 'Sempre que um novo comentário foi escrito.',
  'Write a new comment...' => 'Escreva um novo comentário...',
  'Write a new reply...' => 'Escreva uma nova resposta...',
  'comment' => 'comentário',
  '{displayName} wrote a new comment ' => '{displayName} comentou:',
];
